conf.file.to.list: Sampled configurations as R lists.

View source: R/inputoutput.R

conf.file.to.listR Documentation

Sampled configurations as R lists.

Description

conf.file.to.list is used to load into R the sampled configurations saved by the function spavs in a file.

Usage

conf.file.to.list(filename, burn.in = 0)

Arguments

filename

the file where the sampled configurations are saved.

burn.in

the number of sampled configurations that are omitted (i.e., the first burn.in configurations are not loaded). If configurations are written out at every iteration, this is the standard burn-in.

Value

The output is a list whose elements are lists. The i-th list, list[[i]], represents a configuration, whose elements are its components: list[[i]][[j]]$x is the vector of the indices of the predictors and list[[i]][[j]]$y that of the responses, in the j-th component of the i-th configuration.

Examples

  conf.file.to.list("run1_t1_conf.txt")

stefanomonni/spavs documentation built on April 5, 2022, 1:26 a.m.