| conf.file.to.list | R Documentation |
conf.file.to.list is used to load into R the sampled configurations saved by the function spavs in a file.
conf.file.to.list(filename, burn.in = 0)
filename |
the file where the sampled configurations are saved. |
burn.in |
the number of sampled configurations that are omitted (i.e., the first |
The output is a list whose elements are lists. The i-th list, list[[i]], represents a configuration, whose elements are its components: list[[i]][[j]]$x is the vector of the indices of the predictors and list[[i]][[j]]$y that of the responses, in the j-th component of the i-th configuration.
conf.file.to.list("run1_t1_conf.txt")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.